<?php

namespace Drupal\custom_elements\Processor;

use Drupal\Core\Field\FieldItemInterface;
use Drupal\custom_elements\CustomElement;
use Drupal\custom_elements\CustomElementGeneratorTrait;

/**
 * Default processor for media field items.
 */
class MediaReferenceFieldItemProcessor implements CustomElementProcessorInterface {

  use CustomElementGeneratorTrait;

  /**
   * {@inheritdoc}
   */
  public function supports($data, $viewMode) {
    if ($data instanceof FieldItemInterface) {
      $field_definition = $data->getFieldDefinition();
      return $field_definition->getType() == 'entity_reference' &&
        $field_definition->getFieldStorageDefinition()->getSetting('target_type') == 'media';
    }
    else {
      return FALSE;
    }
  }

  /**
   * {@inheritdoc}
   */
  public function addtoElement($data, CustomElement $element, $viewMode) {
    assert($data instanceof FieldItemInterface);
    $field_item = $data;

    /** @var \Drupal\media\MediaInterface $media_entity */
    if ($media_entity = $field_item->entity) {
      $access = $media_entity->access('view', NULL, TRUE);
      $element->addCacheableDependency($access);
      if ($access->isAllowed()) {
        $media_element = $this->getCustomElementGenerator()->generate($media_entity, $viewMode);
        // Set element content from media element to avoid a wrapper tag.
        $element->setFromCustomElement($media_element);
        $element->addCacheableDependency($media_entity);
      }
    }
  }

}
